@@ -108,24 +108,7 @@ for test in $2; do
     parse_test $test
 done
 
-if [ "$1" = "--automake" ]; then
-    echo "# This file is autogenerated by ./tests/update-test-matrix, don't edit"
-    echo "TEST_MATRIX= \\"
-    for f in $tests; do
-        echo "	${f} \\"
-    done
-    echo "	\$(NULL)"
-    echo "TEST_MATRIX_DIST= \\"
-    for f in $dist_tests; do
-        echo "	${f} \\"
-    done
-    echo "	\$(NULL)"
-    echo "TEST_MATRIX_EXTRA_DIST= \\"
-    for f in $extra_dist_tests; do
-        echo "	${f} \\"
-    done
-    echo "	\$(NULL)"
-elif [ "$1" = "--meson" ]; then
+if [ "$1" = "--meson" ]; then
     echo "# This file is autogenerated by ./tests/update-test-matrix, don't edit"
     for f in $tests $dist_tests; do
         f="${f#tests/}"
